'\" Copyright (c) 1994 The Board of Trustees of The Leland Stanford
'\" Junior University.  All rights reserved.
'\" 
'\" Permission to use, copy, modify and distribute this software and its
'\" documentation for any purpose is hereby granted without fee, provided
'\" that the above copyright notice and this permission notice appear in
'\" all copies of this software and that you do not sell the software.
'\" Commercial licensing is available by contacting the author.
'\" 
'\" THE SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY OF ANY KIND,
'\" EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
'\" WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
'\" 
'\" Author:
'\"    Phil Lacroute
'\"    Computer Systems Laboratory
'\"    Electrical Engineering Dept.
'\"    Stanford University
'\" 
'\" $Date: 1994/12/31 19:49:53 $
'\" $Revision: 1.1 $
'\"
'\" Macros
'\" .FS <type>  --  function start
'\"     <type> is return type of function
'\"     name and arguments follow on next line
.de FS
.PD 0v
.PP
\\$1
.HP 8
..
'\" .FA  --  function arguments
'\"     one argument declaration follows on next line
.de FA
.IP " " 4
..
'\" .FE  --  function end
'\"     end of function declaration
.de FE
.PD
..
'\" .DS  --  display start
.de DS
.IP " " 4
..
'\" .DE  --  display done
.de DE
.LP
..
.TH vpSeti 3 "" VolPack
.SH NAME
vpSeti, vpSetd \- set the value of an option
.SH SYNOPSIS
#include <volpack.h>
.sp
.FS vpResult
\fBvpSeti(\fIvpc, option, value\fB)\fR
.FA
vpContext *\fIvpc;\fR
.FA
int \fIoption;\fR
.FA
int \fIvalue;\fR
.FE
.sp
.FS vpResult
\fBvpSetd(\fIvpc, option, value\fB)\fR
.FA
vpContext *\fIvpc;\fR
.FA
int \fIoption;\fR
.FA
double \fIvalue;\fR
.FE
.SH ARGUMENTS
.IP \fIvpc\fR
VolPack context from \fBvpCreateContext.\fR
.IP \fIoption\fR
Constant that specifies the option to be set.
.IP \fIvalue\fR
New value for the option.
.SH DESCRIPTION
These functions are used to set the values of integer- or
double-valued options in a rendering context.  The following list
summarizes the integer-valued options that can be set with
\fBvpSeti\fR:
.IP VP_CONCAT_MODE
Choose whether transformation matrices are premultiplied or
postmultiplied.  If \fIvalue\fR is VP_CONCAT_LEFT then matrices are
premultiplied.  If \fIvalue\fR is VP_CONCAT_RIGHT then matrices are
postmultiplied.  Default: VP_CONCAT_RIGHT.
.IP VP_DEPTH_CUE_SIZE_HINT
Set the suggested number of entries in the depth cueing lookup table.
See vpSetDepthCueing(3).  Default: none
.IP VP_INT_WIDTH_HINT
Set the suggested width (in pixels) of the intermediate image work
buffer.  See vpRenderRawVolume(3).  Default: none
.IP VP_INT_HEIGHT_HINT
Set the suggested height (in pixels) of the intermediate image work
buffer.  See vpRenderRawVolume(3).  Default: none
.IP VP_SHADOW_LIGHT
Get the current shadow light (see vpSetShadowLookupShader(3)).
Legal values are VP_LIGHT0, VP_LIGHT1, ..., VP_LIGHT5.  Default: VP_LIGHT0
.IP VP_SHADOW_WIDTH_HINT
Set the suggested width (in pixels) of the shadow buffer
(see vpSetShadowLookupShader(3)).  Default: none
.IP VP_SHADOW_HEIGHT_HINT
Set the suggested height (in pixels) of the shadow buffer
(see vpSetShadowLookupShader(3)).  Default: none
.IP VP_SHADOW_BIAS
Set the current shadow bias value (see vpSetShadowLookupShader(3)).
The value is an integral distance in units of voxels.  Default: 4
.IP VP_AXIS_OVERRIDE
Force the rendering routine to composite along a particular principle
viewing axis, regardless of the current viewing direction.  Legal
values are VP_X_AXIS, VP_Y_AXIS or VP_Z_AXIS.  Set the value to
VP_NO_AXIS to let VolPack choose the optimal axis automatically (the
default).  This option is normally used only for debugging.
.IP VP_TRACE_SHADOW_K
When pixel tracing is enabled (see vpTracePixel(3)) and shadows are
enabled (the VP_SHADOW option to vpEnable(3)), this option is used to
choose one shadow buffer pixel to trace.  The value must be a voxel
slice number.  The shadow buffer pixel that gets traced is the shadow
pixel that affects the traced image pixel at the indicated slice.
.PP
The following list summarizes the double-valued options that can be
set with \fBvpSetd\fR:
.IP VP_DEPTH_CUE_QUANTIZATION
Set the difference in depth between two adjacent entries in the depth
cueing lookup table (see vpSetDepthCueing(3)).  Must be greater than 0.0
and less than 1.0.  Default: 1/255
.IP VP_MAX_RAY_OPACITY
Set the maximum opacity threshold.  During rendering, when a pixel's
opacity reaches this threshold no more voxels are composited into the
pixel.  To maximize performance, the value should be as low as
possible without adversely affecting image quality.  Must be in the range
0.0-1.0 (1.0 is the default and 0.95 is the suggested value).
Default: 1.0
.IP VP_MIN_VOXEL_OPACITY
Set the minimum opacity threshold.  During classification, if a
voxel's opacity is less than or equal to this threshold then the voxel
is discarded before rendering.  To maximize performance, the value
should be as high as possible without adversely affecting image
quality.  Must be in the range 0.0-1.0 (0.0 is the default and 0.05 is
the suggested value).
Default: 0.0
.SH ERRORS
The normal return value is VP_OK.  The following error return values
are possible:
.IP VPERROR_BAD_OPTION
The \fIoption\fR argument is invalid.
.IP VPERROR_BAD_VALUE
The \fIvalue\fR argument is invalid or out of range.
.SH SEE ALSO
VolPack(3), vpCreateContext(3), vpGeti(3)
